@@ -33,12 +33,12 @@ class User:
 
     @property
     def data(self):
-        response = get(f"https://discord.com/api/oauth2/@me", headers={"Authorization": f"Bearer {self.code}"})
+        response = get(f"https://discord.com/api/oauth2/@me", headers={"Authorization": f"Bearer {self.auth_token}"})
         response.raise_for_status()
         return response.json()['user']
 
     @property
     def guilds(self):
-        response = get("https://discord.com/api/v8/users/@me/guilds", headers={"Authorization": f"Bearer {self.code}"})
+        response = get("https://discord.com/api/v8/users/@me/guilds", headers={"Authorization": f"Bearer {self.auth_token}"})
         response.raise_for_status()
         return response.json()
